==> fanwindow-mc1.21.2%2Bmc1.21.3-1.4.0-sources.jar: cn/mangofanfan/fanwindow/client/screen/widget/GameModeCardWidget.java <==
package cn.mangofanfan.fanwindow.client.screen.widget;

import net.minecraft.class_1921;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_339;
import net.minecraft.class_437;
import net.minecraft.class_6382;
import net.minecraft.class_7919;
import net.minecraft.class_8100;

public class GameModeCardWidget extends class_339 {
    class_8100 worldCreator;
    class_8100.class_4539 mode;
    class_2960 modePicture;
    class_437 screen;
    class_2561 strongText;
    class_327 textRenderer;
    int borderColor;
    boolean chosen;

    public GameModeCardWidget(class_8100 worldCreator, class_437 screen) {
        super(0, 0, 60, 90, class_2561.method_43473());
        this.worldCreator = worldCreator;
        this.screen = screen;
        this.textRenderer = class_310.method_1551().field_1772;
    }

    public void setMode(class_8100.class_4539 mode) {
        this.mode = mode;
        this.method_47400(class_7919.method_47407(mode.method_48736()));
        switch (mode) {
            case field_20626:
                borderColor = 0xFF2F4F4F;
                modePicture = class_2960.method_60655("fanwindow", "textures/gamemode/creative.png");
                strongText = class_2561.method_43471("selectWorld.gameMode.creative");
                break;
            case field_20625:
                borderColor = 0xFFFFFAFA;
                modePicture = class_2960.method_60655("fanwindow", "textures/gamemode/hardcore.png");
                strongText = class_2561.method_43471("selectWorld.gameMode.hardcore");
                break;
            case field_20624:
                borderColor = 0xFF00BFFF;
                modePicture = class_2960.method_60655("fanwindow", "textures/gamemode/survival.png");
                strongText = class_2561.method_43471("selectWorld.gameMode.survival");
                break;
        }
    }

    public class_8100.class_4539 getMode() {
        return mode;
    }

    public void setChosen(boolean chosen) {
        this.chosen = chosen;
    }

    public boolean isChosen() {
        return this.chosen;
    }

    @Override
    protected void method_48579(class_332 context, int mouseX, int mouseY, float deltaTicks) {
        int bgColor = method_49606() ? 0xFF222222 : 0xFF000000;
        int strongColor = isChosen() ? 0xFFFFFFFF : 0xFF000000;
        int strongBgColor = isChosen() ? 0xDD000000 : 0xDDFFFFFF;
        // 更改绘制顺序，先画底色，再画纹理，再画上层
        context.method_25294(method_46426() + 1, method_46427() + 1, method_46426() + field_22758 - 1, method_46427() + field_22759 - 1, bgColor);
        context.method_25290(class_1921::method_62277, modePicture, method_46426() + 1, method_46427() + 1,  0, 0, field_22758 - 2, field_22759 - 2, field_22758 - 2, field_22759 - 2);
        context.method_25294(method_46426() + 1, method_46427() + 71, method_46426() + field_22758 - 1, method_46427() + field_22759 - 1, strongBgColor);
        context.method_51440(screen.method_64506(), strongText, method_46426() + 5, method_46427() + 76, field_22758 - 12, strongColor);
        context.method_49601(method_46426(), method_46427(), field_22758, field_22759, borderColor);
    }

    @Override
    public void method_25348(double mouseX, double mouseY) {
        super.method_25348(mouseX, mouseY);
        worldCreator.method_48704(mode);
    }

    @Override
    protected void method_47399(class_6382 builder) {}
}

==> fanwindow-mc1.21.9%2Bmc1.21.10-1.4.0-sources.jar: cn/mangofanfan/fanwindow/client/screen/widget/GameModeCardWidget.java <==
package cn.mangofanfan.fanwindow.client.screen.widget;

import net.minecraft.class_10799;
import net.minecraft.class_11909;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_339;
import net.minecraft.class_437;
import net.minecraft.class_6382;
import net.minecraft.class_7919;
import net.minecraft.class_8100;

public class GameModeCardWidget extends class_339 {
    class_8100 worldCreator;
    class_8100.class_4539 mode;
    class_2960 modePicture;
    class_437 screen;
    class_2561 strongText;
    int borderColor;
    boolean chosen;

    public GameModeCardWidget(class_8100 worldCreator, class_437 screen) {
        super(0, 0, 60, 90, class_2561.method_43473());
        this.worldCreator = worldCreator;
        this.screen = screen;
    }

    public void setMode(class_8100.class_4539 mode) {
        this.mode = mode;
        this.method_47400(class_7919.method_47407(mode.method_48736()));
        switch (mode) {
            case field_20626:
                borderColor = 0xFF2F4F4F;
                modePicture = class_2960.method_60655("fanwindow", "textures/gamemode/creative.png");
                strongText = class_2561.method_43471("selectWorld.gameMode.creative");
                break;
            case field_20625:
                borderColor = 0xFFFFFAFA;
                modePicture = class_2960.method_60655("fanwindow", "textures/gamemode/hardcore.png");
                strongText = class_2561.method_43471("selectWorld.gameMode.hardcore");
                break;
            case field_20624:
                borderColor = 0xFF00BFFF;
                modePicture = class_2960.method_60655("fanwindow", "textures/gamemode/survival.png");
                strongText = class_2561.method_43471("selectWorld.gameMode.survival");
                break;
        }
    }

    public class_8100.class_4539 getMode() {
        return mode;
    }

    public void setChosen(boolean chosen) {
        this.chosen = chosen;
    }

    public boolean isChosen() {
        return this.chosen;
    }

    @Override
    protected void method_48579(class_332 context, int mouseX, int mouseY, float deltaTicks) {
        int bgColor = method_49606() ? 0xFF222222 : 0xFF000000;
        int strongColor = isChosen() ? 0xFFFFFFFF : 0xFF000000;
        int strongBgColor = isChosen() ? 0xDD000000 : 0xDDFFFFFF;
        context.method_25294(method_46426() + 1, method_46427() + 1, method_46426() + field_22758 - 1, method_46427() + field_22759 - 1, bgColor);
        context.method_25290(class_10799.field_56883, modePicture, method_46426() + 1, method_46427() + 1,  0, 0, field_22758 - 2, field_22759 - 2, field_22758 - 2, field_22759 - 2);
        context.method_25294(method_46426() + 1, method_46427() + 71, method_46426() + field_22758 - 1, method_46427() + field_22759 - 1, strongBgColor);
        context.method_51440(screen.method_64506(), strongText, method_46426() + 5, method_46427() + 76, field_22758 - 12, strongColor, false);
        // context.drawBorder(getX(), getY(), width, height, borderColor);
        // 绘制边框的方法不知道到哪里去了，所以先手绘一个差不多的边框叭（委屈巴巴）
        context.method_51738(method_46426(), method_46426() + field_22758 - 1, method_46427(), borderColor);
        context.method_51738(method_46426(), method_46426() + field_22758 - 1, method_46427() + field_22759 - 1, borderColor);
        context.method_51742(method_46426(), method_46427(), method_46427() + field_22759, borderColor);
        context.method_51742(method_46426() + field_22758 - 1, method_46427(), method_46427() + field_22759, borderColor);
    }

    @Override
    public void method_25348(class_11909 click, boolean doubled) {
        super.method_25348(click, doubled);
        worldCreator.method_48704(mode);
    }

    @Override
    protected void method_47399(class_6382 builder) {}
}
